@@ -1,7 +1,7 @@
 /*
  * ct_config.h
  *
- * Copyright 2009-2020
+ * Copyright 2009-2021
  * Giuseppe Penone <giuspen@gmail.com>
  * Evgenii Gurianov <https://github.com/txe>
  *
@@ -34,13 +34,22 @@ class CtConfig
 {
 public:
     CtConfig();
-    virtual ~CtConfig();
+    CtConfig(const std::string filepath);
 
     static const fs::path ConfigFilename;
+    static const fs::path PrintPageSetupFilename;
     static const fs::path LangFilename;
+    static const fs::path LogFilename;
+    static const fs::path ConfigLanguageSpecsDirname;
+    static const fs::path ConfigStylesDirname;
+    static const fs::path UserStyleTemplate;
 
-    bool load_from_file(const fs::path& filepath = fs::get_cherrytree_config_filepath());
-    bool write_to_file(const fs::path& filepath =  fs::get_cherrytree_config_filepath());
+    bool getInitLoadFromFileOk() { return _initLoadFromFileOk; }
+    bool write_to_file(const std::string filepath = "");
+    void move_from_tmp();
+
+    void update_user_style(const unsigned num);
+    static std::string get_user_style_id(const unsigned num);
 
     // [state]
     CtRecentDocsRestore                         recentDocsRestore;
@@ -77,9 +86,10 @@ public:
     // [editor]
     std::string                                 syntaxHighlighting{CtConst::RICH_TEXT_ID};
     std::string                                 autoSynHighl{CtConst::SYN_HIGHL_BASH};
-    std::string                                 rtStyleScheme{CtConst::STYLE_SCHEME_DARK};
-    std::string                                 ptStyleScheme{CtConst::STYLE_SCHEME_DARK};
-    std::string                                 taStyleScheme{CtConst::STYLE_SCHEME_LIGHT};
+    std::string                                 rtStyleScheme{"user-1"};
+    std::string                                 ptStyleScheme{"user-1"};
+    std::string                                 taStyleScheme{"user-2"};
+    std::string                                 coStyleScheme{"cobalt-darkened"};
     bool                                        enableSpellCheck{false};
     std::string                                 spellCheckLang;
     bool                                        showLineNumbers{false};
@@ -109,6 +119,7 @@ public:
     int                                         relativeWrappedSpace{50};
     Glib::ustring                               hRule{"~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~"};
     CtStringSplittable                          specialChars{CtConst::SPECIAL_CHARS_DEFAULT};
+    Glib::ustring                               lastSpecialChar{};
     CtStringSplittable                          selwordChars{CtConst::SELWORD_CHARS_DEFAULT};
     CtStringSplittable                          charsListbul{CtConst::CHARS_LISTBUL_DEFAULT};
     CtStringSplittable                          charsToc{CtConst::CHARS_TOC_DEFAULT};
@@ -160,9 +171,17 @@ public:
     // [colors]
     std::string                                 ttDefFg{CtConst::TREE_TEXT_LIGHT_FG};
     std::string                                 ttDefBg{CtConst::TREE_TEXT_LIGHT_BG};
+    std::string                                 monospaceFg{CtConst::DEFAULT_MONOSPACE_FG};
     std::string                                 monospaceBg{CtConst::DEFAULT_MONOSPACE_BG};
     bool                                        msDedicatedFont{false};
     Glib::ustring                               monospaceFont{"Monospace 9"};
+    CtScalableTag                               scalableH1{CtConst::SCALABLE_H1_DEFAULT};
+    CtScalableTag                               scalableH2{CtConst::SCALABLE_H2_DEFAULT};
+    CtScalableTag                               scalableH3{CtConst::SCALABLE_H3_DEFAULT};
+    CtScalableTag                               scalableH4{CtConst::SCALABLE_H4_DEFAULT};
+    CtScalableTag                               scalableH5{CtConst::SCALABLE_H5_DEFAULT};
+    CtScalableTag                               scalableH6{CtConst::SCALABLE_H6_DEFAULT};
+    CtScalableTag                               scalableSmall{CtConst::SCALABLE_SMALL_DEFAULT};
     std::string                                 colorPalette{"#000000:#ffffff:#7f7f7f:#ff0000:#a020f0:"
                                                              "#0000ff:#add8e6:#00ff00:#ffff00:#ffa500:"
                                                              "#e6e6fa:#a52a2a:#8b6914:#1e90ff:#ffc0cb:"
@@ -171,9 +190,18 @@ public:
     std::string                                 colLinkNode{CtConst::COLOR_48_LINK_NODE};
     std::string                                 colLinkFile{CtConst::COLOR_48_LINK_FILE};
     std::string                                 colLinkFold{CtConst::COLOR_48_LINK_FOLD};
+    std::array<std::string,CtConst::NUM_USER_STYLES> userStyleTextFg{CtConst::USER_STYLE_TEXT_FG};
+    std::array<std::string,CtConst::NUM_USER_STYLES> userStyleTextBg{CtConst::USER_STYLE_TEXT_BG};
+    std::array<std::string,CtConst::NUM_USER_STYLES> userStyleSelectionFg{CtConst::USER_STYLE_SELECTION_FG};
+    std::array<std::string,CtConst::NUM_USER_STYLES> userStyleSelectionBg{CtConst::USER_STYLE_SELECTION_BG};
+    std::array<std::string,CtConst::NUM_USER_STYLES> userStyleCursor{CtConst::USER_STYLE_CURSOR};
+    std::array<std::string,CtConst::NUM_USER_STYLES> userStyleCurrentLineBg{CtConst::USER_STYLE_CURRENT_LINE_BG};
+    std::array<std::string,CtConst::NUM_USER_STYLES> userStyleLineNumbersFg{CtConst::USER_STYLE_LINE_NUMBERS_FG};
+    std::array<std::string,CtConst::NUM_USER_STYLES> userStyleLineNumbersBg{CtConst::USER_STYLE_LINE_NUMBERS_BG};
 
     // [misc]
     std::string                                 toolbarUiList{CtConst::TOOLBAR_VEC_DEFAULT};
+    bool                                        bookmarksInTopMenu{true};
     bool                                        systrayOn{false};
     bool                                        startOnSystray{false};
     bool                                        useAppInd{false};
@@ -183,13 +211,14 @@ public:
     bool                                        wordCountOn{false};
     bool                                        reloadDocLast{true};
     bool                                        winTitleShowDocDir{true};
+    bool                                        nodeNameHeaderShowFullPath{true};
     bool                                        modTimeSentinel{false};
     bool                                        backupCopy{true};
     int                                         backupNum{3};
     bool                                        autosaveOnQuit{false};
     bool                                        customBackupDirOn{false};
     std::string                                 customBackupDir{""};
-    int                                         limitUndoableSteps{20};
+    int                                         limitUndoableSteps{10};
     bool                                        usePandoc{true}; // Whether to use Pandoc for exporting
 
     // [keyboard]
@@ -204,20 +233,21 @@ public:
     // [codexec_ext]
     std::map<std::string, std::string>          customCodexecExt;
 
+    // helpers
+    const std::array<CtScalableTag*,7>          scalablesTags{&scalableH1, &scalableH2, &scalableH3,
+                                                              &scalableH4, &scalableH5, &scalableH6,
+                                                              &scalableSmall};
+
 protected:
-    template<class String> bool _populate_string_from_keyfile(const gchar* key, String* pTarget)
-    {
+    template<class String> bool _populate_string_from_keyfile(std::string key, String* pTarget) {
         bool gotIt{false};
-        if (_uKeyFile->has_group(_currentGroup) && _uKeyFile->has_key(_currentGroup, key))
-        {
-            try
-            {
+        if (_uKeyFile->has_group(_currentGroup) && _uKeyFile->has_key(_currentGroup, key)) {
+            try {
                 *pTarget = _uKeyFile->get_string(_currentGroup, key);
                 gotIt = true;
             }
-            catch (Glib::KeyFileError& kferror)
-            {
-                _unexpected_keyfile_error(key, kferror);
+            catch (Glib::KeyFileError& kferror) {
+                _unexpected_keyfile_error(key.c_str(), kferror);
             }
         }
         return gotIt;
@@ -231,9 +261,16 @@ protected:
     void _populate_keyfile_from_data();
     void _unexpected_keyfile_error(const gchar* key, const Glib::KeyFileError& kferror);
 
+    bool _load_from_file();
+    void _ensure_user_styles_exist();
+
     static const size_t _maxTempKeySize{20};
 
     gchar _tempKey[_maxTempKeySize];
     std::unique_ptr<Glib::KeyFile> _uKeyFile;
     std::string _currentGroup;
+    bool _initLoadFromFileOk{false};
+
+    const fs::path _configFilepath;
+    const fs::path _configFilepathTmp;
 };
