@@ -1,7 +1,7 @@
 /*
  * ct_extern const.h
  *
- * Copyright 2009-2020
+ * Copyright 2009-2021
  * Giuseppe Penone <giuspen@gmail.com>
  * Evgenii Gurianov <https://github.com/txe>
  *
@@ -82,23 +82,41 @@ const inline static Glib::ustring CHARS_TODO_DEFAULT         {"☐☑☒"};
 const inline static Glib::ustring CHARS_SMART_DQUOTE_DEFAULT {"“”"};
 const inline static Glib::ustring CHARS_SMART_SQUOTE_DEFAULT {"‘’"};
 
-const inline static gchar* COLOR_48_LINK_WEBS   {"#00008989ffff"};
-const inline static gchar* COLOR_48_LINK_NODE   {"#071c838e071c"};
-const inline static gchar* COLOR_48_LINK_FILE   {"#8b8b69691414"};
-const inline static gchar* COLOR_48_LINK_FOLD   {"#7f7f7f7f7f7f"};
-const inline static gchar* COLOR_48_YELLOW      {"#bbbbbbbb0000"};
-const inline static gchar* COLOR_48_WHITE       {"#ffffffffffff"};
-const inline static gchar* COLOR_48_BLACK       {"#000000000000"};
-const inline static gchar* COLOR_24_BLACK       {"#000000"};
-const inline static gchar* COLOR_24_WHITE       {"#ffffff"};
-const inline static gchar* COLOR_24_BLUEBG      {"#001b33"};
-const inline static gchar* COLOR_24_LBLACK      {"#0b0c0c"};
-const inline static gchar* COLOR_24_GRAY        {"#e0e0e0"};
-const inline static gchar* DEFAULT_MONOSPACE_BG {"#7f7f7f"};
+const inline static gchar* COLOR_48_LINK_WEBS     {"#00008989ffff"};
+const inline static gchar* COLOR_48_LINK_NODE     {"#071c838e071c"};
+const inline static gchar* COLOR_48_LINK_FILE     {"#8b8b69691414"};
+const inline static gchar* COLOR_48_LINK_FOLD     {"#7f7f7f7f7f7f"};
+const inline static gchar* COLOR_48_YELLOW        {"#bbbbbbbb0000"};
+const inline static gchar* COLOR_48_WHITE         {"#ffffffffffff"};
+const inline static gchar* COLOR_48_BLACK         {"#000000000000"};
+const inline static gchar* COLOR_24_BLACK         {"#000000"};
+const inline static gchar* COLOR_24_WHITE         {"#ffffff"};
+const inline static gchar* COLOR_24_BLUEBG        {"#001b33"};
+const inline static gchar* COLOR_24_LBLACK        {"#0b0c0c"};
+const inline static gchar* COLOR_24_LGRAY         {"#e0e0e0"};
+const inline static gchar* COLOR_24_DGRAY         {"#7f7f7f"};
+const inline static gchar* SCALABLE_H1_DEFAULT    {"1728;;;0;0;0"};
+const inline static gchar* SCALABLE_H2_DEFAULT    {"1440;;;0;0;0"};
+const inline static gchar* SCALABLE_H3_DEFAULT    {"1200;;;0;0;0"};
+const inline static gchar* SCALABLE_H4_DEFAULT    {"1150;;;0;0;0"};
+const inline static gchar* SCALABLE_H5_DEFAULT    {"1100;;;0;0;0"};
+const inline static gchar* SCALABLE_H6_DEFAULT    {"1050;;;0;0;0"};
+const inline static gchar* SCALABLE_SMALL_DEFAULT  {"833;;;0;0;0"};
 const inline static gchar* TREE_TEXT_DARK_FG      {COLOR_24_WHITE};
 const inline static gchar* TREE_TEXT_DARK_BG      {COLOR_24_BLUEBG};
 const inline static gchar* TREE_TEXT_LIGHT_FG     {COLOR_24_LBLACK};
-const inline static gchar* TREE_TEXT_LIGHT_BG     {COLOR_24_GRAY};
+const inline static gchar* TREE_TEXT_LIGHT_BG     {COLOR_24_LGRAY};
+const inline static gchar* DEFAULT_MONOSPACE_FG   {COLOR_24_LGRAY};
+const inline static gchar* DEFAULT_MONOSPACE_BG   {COLOR_24_DGRAY};
+const inline static unsigned NUM_USER_STYLES{2};
+const inline static std::array<std::string,NUM_USER_STYLES> USER_STYLE_TEXT_FG{COLOR_24_WHITE, COLOR_24_BLACK};
+const inline static std::array<std::string,NUM_USER_STYLES> USER_STYLE_TEXT_BG{COLOR_24_BLACK, COLOR_24_WHITE};
+const inline static std::array<std::string,NUM_USER_STYLES> USER_STYLE_SELECTION_FG{COLOR_24_WHITE, COLOR_24_WHITE};
+const inline static std::array<std::string,NUM_USER_STYLES> USER_STYLE_SELECTION_BG{"#0088ff", "#43ace8"};
+const inline static std::array<std::string,NUM_USER_STYLES> USER_STYLE_CURSOR{COLOR_24_WHITE, COLOR_24_BLACK};
+const inline static std::array<std::string,NUM_USER_STYLES> USER_STYLE_CURRENT_LINE_BG{"#003b70", "#eef6ff"};
+const inline static std::array<std::string,NUM_USER_STYLES> USER_STYLE_LINE_NUMBERS_FG{"#777777", COLOR_24_BLACK};
+const inline static std::array<std::string,NUM_USER_STYLES> USER_STYLE_LINE_NUMBERS_BG{"#000d1a", "#d6d2d0"};
 
 const inline static gchar* GTKSPELLCHECK_TAG_NAME  {"gtkspellchecker-misspelled"};
 const inline static gchar* TAG_WEIGHT              {"weight"};
@@ -186,6 +204,8 @@ const inline static std::array<std::string_view, 4> WEB_LINK_STARTERS {
     "www.",
     "ftp://"
 };
+// https://stackoverflow.com/questions/1547899/which-characters-make-a-url-invalid
+const inline static char URL_INVALID_CHARS[]{" \n\r\t\"<>\\^`{}"};
 
 const inline static std::array<std::string_view, 11> TAG_PROPERTIES {
     TAG_WEIGHT,
@@ -214,23 +234,16 @@ const inline static gchar* TOOLBAR_VEC_DEFAULT {
     "separator,*,ct_save,export_pdf,separator,"
     "find_in_allnodes,separator,handle_bull_list,handle_num_list,handle_todo_list,fmt_indent,fmt_unindent,"
     "separator,handle_image,handle_table,handle_codebox,handle_embfile,"
-    "handle_link,handle_anchor,separator,fmt_rm,fmt_color_fg,"
+    "handle_link,handle_anchor,separator,fmt_clone,fmt_latest,fmt_rm,fmt_color_fg,"
     "fmt_color_bg,fmt_bold,fmt_italic,fmt_underline,fmt_strikethrough,"
     "fmt_h1,fmt_h2,fmt_h3,fmt_small,fmt_superscript,fmt_subscript,fmt_monospace"
 };
 
-const inline static std::array<const gchar*, 18>  TOOLBAR_VEC_BLACKLIST {
-    "anch_cut", "anch_copy", "anch_del", "anch_edit", "emb_file_cut",
-    "emb_file_copy", "emb_file_del", "emb_file_save", "emb_file_open", "emb_file_rename",
-    "img_save", "img_edit", "img_cut", "img_copy", "img_del",
-    "img_link_edit", "img_link_dismiss", "toggle_show_mainwin"
-};
-
 const inline static gchar* LANG_DEFAULT{"default"};
 
-const inline static std::array<const gchar*, 22> AVAILABLE_LANGS {
-    LANG_DEFAULT, "bg", "cs", "de", "el", "en", "es", "fi", "fr", "hy", "it",
-    "ja", "lt", "nl", "pl", "pt_BR", "ru", "sl", "sv", "tr", "uk", "zh_CN"
+const inline static std::array<const gchar*, 26> AVAILABLE_LANGS {
+    LANG_DEFAULT, "bg", "cs", "de", "el", "en", "es", "fi", "fr", "hr", "hy", "it",
+    "ja", "kk_KZ", "ko", "lt", "nl", "pl", "pt_BR", "ro", "ru", "sl", "sv", "tr", "uk", "zh_CN"
 };
 
 const inline static int NODE_ICON_CODE_ID          {38};
@@ -240,7 +253,7 @@ const inline static int NODE_ICON_SIZE             {16};
 const inline static int MAX_TOOLTIP_LINK_CHARS     {150};
 
 // former NODES_STOCK
-const inline static std::array<const gchar*, 49> NODE_CUSTOM_ICONS {
+const inline static std::array<const gchar*, 126> NODE_CUSTOM_ICONS {
     nullptr,            // NEVER USED
     "ct_circle-green",  //  1
     "ct_circle-yellow", //  2
@@ -290,6 +303,83 @@ const inline static std::array<const gchar*, 49> NODE_CUSTOM_ICONS {
     "ct_xml",           // 46
     "ct_c",             // 47
     "ct_cpp",           // 48
+    "ct_perl",          // 49
+    "ct_pin",           // 50
+    "ct_anchor",        // 51
+    "ct_edit",          // 52
+    "ct_save",          // 53
+    "ct_execute",       // 54
+    "ct_preferences",   // 55
+    "ct_clear",         // 56
+    "ct_stop",          // 57
+    "ct_close",         // 58
+    "ct_quit-app",      // 59
+    "ct_file",          // 60
+    "ct_print",         // 61
+    "ct_file_icon",     // 62
+    "ct_link_handle",   // 63
+    "ct_link_website",  // 64
+    "ct_network",       // 65
+    "ct_go-back",       // 66
+    "ct_go-down",       // 67
+    "ct_go-forward",    // 68
+    "ct_go-up",         // 69
+    "ct_go-jump",       // 70
+    "ct_zoom-out",      // 71
+    "ct_zoom-in",       // 72
+    "ct_bg",            // 73
+    "ct_cs",            // 74
+    "ct_de",            // 75
+    "ct_el",            // 76
+    "ct_en",            // 77
+    "ct_en_US",         // 78
+    "ct_es",            // 79
+    "ct_fi",            // 80
+    "ct_fr",            // 81
+    "ct_hy",            // 82
+    "ct_it",            // 83
+    "ct_ja",            // 84
+    "ct_lt",            // 85
+    "ct_nl",            // 86
+    "ct_pl",            // 87
+    "ct_pt_BR",         // 88
+    "ct_ru",            // 89
+    "ct_sl",            // 90
+    "ct_sv",            // 91
+    "ct_tr",            // 92
+    "ct_uk",            // 93
+    "ct_zh_CN",         // 94
+    "ct_sports",        // 95
+    "ct_briefcase",     // 96
+    "ct_camera",        // 97
+    "ct_chart",         // 98
+    "ct_clapperboard",  // 99
+    "ct_maths",        // 100
+    "ct_games",        // 101
+    "ct_globe",        // 102
+    "ct_server",       // 103
+    "ct_money",        // 104
+    "ct_painting",     // 105
+    "ct_puzzle",       // 106
+    "ct_shopping",     // 107
+    "ct_heart",        // 108
+    "ct_smile",        // 109
+    "ct_smile_cool",   // 110
+    "ct_smile_surpr",  // 111
+    "ct_skull",        // 112
+    "ct_no_access",    // 113
+    "ct_ruby",         // 114
+    "ct_tux",          // 115
+    "ct_gnome",        // 116
+    "ct_debian",       // 117
+    "ct_ubuntu",       // 118
+    "ct_freebsd",      // 119
+    "ct_win10",        // 120
+    "ct_win2012",      // 121
+    "ct_ko",           // 122
+    "ct_kk_KZ",        // 123
+    "ct_ro",           // 124
+    "ct_hr"            // 125
 };
 
 // former NODES_ICONS
@@ -307,7 +397,7 @@ const inline static std::array<const gchar*, 11> NODE_CHERRY_ICONS {
     CHERRY_GRAY         // 10
 };
 
-const inline static std::array<std::pair<const gchar*, const gchar*>, 11> NODE_CODE_ICONS {
+const inline static std::array<std::pair<const gchar*, const gchar*>, 12> NODE_CODE_ICONS {
     std::make_pair("python", "ct_python"),
     std::make_pair("python3", "ct_python"),
     std::make_pair("perl", "ct_perl"),
@@ -318,7 +408,8 @@ const inline static std::array<std::pair<const gchar*, const gchar*>, 11> NODE_C
     std::make_pair("html", "ct_html"),
     std::make_pair("xml", "ct_xml"),
     std::make_pair("c", "ct_c"),
-    std::make_pair("cpp", "ct_cpp")
+    std::make_pair("cpp", "ct_cpp"),
+    std::make_pair("ruby", "ct_ruby")
 };
 
 const inline static gchar* CODE_EXEC_TMP_SRC  {"<tmp_src_path>"};
