@@ -1,7 +1,7 @@
 /*
  * ct_dialogs.h
  *
- * Copyright 2009-2020
+ * Copyright 2009-2021
  * Giuseppe Penone <giuspen@gmail.com>
  * Evgenii Gurianov <https://github.com/txe>
  *
@@ -25,10 +25,7 @@
 
 #include "ct_misc_utils.h"
 #include "ct_filesystem.h"
-#include <gtkmm/dialog.h>
-#include <gtkmm/liststore.h>
-#include <gtkmm/treestore.h>
-#include <gtkmm/treeview.h>
+#include <gtkmm.h>
 #include <array>
 
 class CtMainWin;
@@ -150,11 +147,11 @@ public:
 
 namespace CtDialogs {
 
-
 Gtk::TreeIter choose_item_dialog(Gtk::Window& parent,
                                  const Glib::ustring& title,
                                  Glib::RefPtr<CtChooseDialogListStore> model,
-                                 const gchar* single_column_name = nullptr);
+                                 const gchar* single_column_name = nullptr,
+                                 const std::string& pathToSelect = "0");
 
 // Dialog to select between the Selected Node/Selected Node + Subnodes/All Tree
 CtExporting selnode_selnodeandsub_alltree_dialog(Gtk::Window& parent,
@@ -205,6 +202,16 @@ void match_dialog(const Glib::ustring& title,
                   CtMainWin* ctMainWin,
                   Glib::RefPtr<CtMatchDialogStore>& rModel);
 
+void iterated_find_dialog(CtMainWin* pCtMainWin,
+                          CtSearchState& s_state);
+
+std::string dialog_search(Gtk::Window* pParentWin,
+                          const std::string& title,
+                          CtSearchOptions& s_options,
+                          bool replace_on,
+                          bool multiple_nodes,
+                          bool pattern_required);
+
 // Insert/Edit Anchor Name
 Glib::ustring img_n_entry_dialog(Gtk::Window& parent,
                                  const Glib::ustring& title,
@@ -217,26 +224,26 @@ bool link_handle_dialog(CtMainWin& ctMainWin,
                         Gtk::TreeIter sel_tree_iter,
                         CtLinkEntry& link_entries);
 
-struct file_select_args
+struct FileSelectArgs
 {
+    FileSelectArgs(Gtk::Window* win) : pParentWin{win} {}
+
     Gtk::Window*                pParentWin{nullptr};
     fs::path                    curr_folder;
     fs::path                    curr_file_name;
     Glib::ustring               filter_name;
-    std::vector<std::string>    filter_pattern;
-    // std::vector<std::string>    filter_mime; doesn't work with native dialog
-
-    file_select_args(Gtk::Window* win) : pParentWin(win) {}
+    std::vector<Glib::ustring>  filter_pattern;
+    std::vector<Glib::ustring>  filter_mime;
 };
 
 // The Select file dialog, Returns the retrieved filepath or None
-std::string file_select_dialog(const file_select_args& args);
+std::string file_select_dialog(const FileSelectArgs& args);
 
 // The Select folder dialog, returns the retrieved folderpath or None
 std::string folder_select_dialog(const std::string& curr_folder, Gtk::Window* pParentWin);
 
 // The Save file as dialog, Returns the retrieved filepath or None
-std::string file_save_as_dialog(const file_select_args& args);
+std::string file_save_as_dialog(const FileSelectArgs& args);
 
 // Insert/Edit Image
 Glib::RefPtr<Gdk::Pixbuf> image_handle_dialog(Gtk::Window& father_win,
