@@ -1,7 +1,7 @@
 /*
  * ct_export2pdf.h
  *
- * Copyright 2009-2020
+ * Copyright 2009-2021
  * Giuseppe Penone <giuspen@gmail.com>
  * Evgenii Gurianov <https://github.com/txe>
  *
@@ -65,13 +65,29 @@ using CtPangoObjectPtr = std::shared_ptr<CtPangoObject>;
 class CtExport2Pango
 {
 public:
-    Glib::ustring pango_get_from_code_buffer(Glib::RefPtr<Gsv::Buffer> code_buffer, int sel_start, int sel_end);
-    void pango_get_from_treestore_node(CtTreeIter node_iter, int sel_start, int sel_end, std::vector<CtPangoObjectPtr>& out_slots);
+    CtExport2Pango(CtMainWin* pCtMainWin) : _pCtMainWin{pCtMainWin} {}
+
+    Glib::ustring pango_get_from_code_buffer(Glib::RefPtr<Gsv::Buffer> code_buffer,
+                                             int sel_start,
+                                             int sel_end);
+    void pango_get_from_treestore_node(CtTreeIter node_iter,
+                                       int sel_start,
+                                       int sel_end,
+                                       std::vector<CtPangoObjectPtr>& out_slots);
 
 private:
-    void                         _pango_process_slot(int start_offset, int end_offset, Glib::RefPtr<Gtk::TextBuffer> curr_buffer, std::vector<CtPangoObjectPtr>& out_slots);
-    void                         _pango_text_serialize(const Gtk::TextIter& start_iter, Gtk::TextIter end_iter, const CtCurrAttributesMap& curr_attributes, std::vector<CtPangoObjectPtr>& out_slots);
+    void                         _pango_process_slot(int start_offset,
+                                                     int end_offset,
+                                                     Glib::RefPtr<Gtk::TextBuffer> curr_buffer,
+                                                     std::vector<CtPangoObjectPtr>& out_slots);
+    void                         _pango_text_serialize(const Gtk::TextIter& start_iter,
+                                                       Gtk::TextIter end_iter,
+                                                       const CtCurrAttributesMap& curr_attributes,
+                                                       std::vector<CtPangoObjectPtr>& out_slots);
     std::shared_ptr<CtPangoText> _pango_link_url(const Glib::ustring& tagged_text, const Glib::ustring& link, int indent);
+
+private:
+    CtMainWin* const _pCtMainWin;
 };
 
 
@@ -79,18 +95,28 @@ private:
 class CtExport2Pdf
 {
 public:
-    CtExport2Pdf(CtMainWin* pCtMainWin) { _pCtMainWin = pCtMainWin; }
+    CtExport2Pdf(CtMainWin* pCtMainWin) : _pCtMainWin{pCtMainWin} {}
 
-    void node_export_print(const fs::path& pdf_filepath, CtTreeIter tree_iter, const CtExportOptions& options, int sel_start, int sel_end);
-    void node_and_subnodes_export_print(const fs::path& pdf_filepath, CtTreeIter tree_iter, const CtExportOptions& options);
-    void tree_export_print(const fs::path& pdf_filepath, CtTreeIter tree_iter, const CtExportOptions& options);
+    void node_export_print(const fs::path& pdf_filepath,
+                           CtTreeIter tree_iter,
+                           const CtExportOptions& options,
+                           int sel_start,
+                           int sel_end);
+    void node_and_subnodes_export_print(const fs::path& pdf_filepath,
+                                        CtTreeIter tree_iter,
+                                        const CtExportOptions& options);
+    void tree_export_print(const fs::path& pdf_filepath,
+                           CtTreeIter tree_iter,
+                           const CtExportOptions& options);
 
 private:
-    void             _nodes_all_export_print_iter(CtTreeIter tree_iter, const CtExportOptions& options, std::vector<CtPangoObjectPtr>& tree_pango_slots);
+    void             _nodes_all_export_print_iter(CtTreeIter tree_iter,
+                                                  const CtExportOptions& options,
+                                                  std::vector<CtPangoObjectPtr>& tree_pango_slots);
     CtPangoObjectPtr _generate_pango_node_name(CtTreeIter tree_iter);
 
 private:
-    CtMainWin* _pCtMainWin;
+    CtMainWin* const _pCtMainWin;
 };
 
 
@@ -128,9 +154,16 @@ struct CtPageCodebox : public CtPageElement
 struct CtPageTable : public CtPageElement
 {
     using TableLayouts = std::vector<std::vector<Glib::RefPtr<Pango::Layout>>>;
-    CtPageTable(int x, TableLayouts layouts, int col_min) : CtPageElement(x), layouts(layouts), col_min(col_min) {}
+    CtPageTable(const int x, const TableLayouts layouts, const CtTableColWidths& col_widths, const double page_dpi_scale)
+     : CtPageElement{x}
+     , layouts{layouts}
+    {
+        for (auto col_width : col_widths) {
+            colWidths.push_back(col_width*page_dpi_scale);
+        }
+    }
     TableLayouts layouts;
-    int          col_min;
+    CtTableColWidths colWidths;
 };
 using CtPageElementPtr = std::shared_ptr<CtPageElement>;
 
@@ -215,9 +248,15 @@ private:
                                                        Glib::ustring& first_split, Glib::ustring& second_split);
 
     CtPageTable::TableLayouts   _table_get_layouts(CtTable* table, const int first_row, const int last_row, const Glib::RefPtr<Gtk::PrintContext>& context);
-    void                        _table_get_grid(const CtPageTable::TableLayouts& table_layouts, const int col_min, std::vector<double>& rows_h, std::vector<double>& cols_w);
+    void                        _table_get_grid(const CtPageTable::TableLayouts& table_layouts,
+                                                const CtTableColWidths& col_widths,
+                                                std::vector<double>& rows_h,
+                                                std::vector<double>& cols_w);
     double                      _table_get_width_height(std::vector<double>& data);
-    int                         _table_split_content(CtTable* table, const int start_row, const int check_height, const Glib::RefPtr<Gtk::PrintContext>& context);
+    int                         _table_split_content(CtTable* table,
+                                                     const int start_row,
+                                                     const int check_height,
+                                                     const Glib::RefPtr<Gtk::PrintContext>& context);
 
     void _draw_codebox_box(Cairo::RefPtr<Cairo::Context> cairo_context, double x0, double y0, double codebox_width, double codebox_height);
     void _draw_codebox_code(Cairo::RefPtr<Cairo::Context> cairo_context, Glib::RefPtr<Pango::Layout> codebox_layout, double x0, double y0);
