@@ -1,7 +1,7 @@
 /*
   ct_filesystem.cc
  *
- * Copyright 2009-2020
+ * Copyright 2009-2021
  * Giuseppe Penone <giuspen@gmail.com>
  * Evgenii Gurianov <https://github.com/txe>
  *
@@ -40,6 +40,23 @@ static fs::path _exePath;
 static fs::path _portableConfigDir;
 static std::unordered_map<std::string, std::pair<std::string,std::string>> _alteredLocaleEnvVars;
 
+// replacement of Glib::canonicalize_filename for Glibmm < 2.64
+std::string legacy_canonicalize_filename(const std::string& filename, const std::string& relative_to/*= ""*/)
+{
+    std::string retFilepath;
+    GFile* pGFile{nullptr};
+    if (not Glib::path_is_absolute(filename) and not relative_to.empty()) {
+        pGFile = g_file_new_for_path(Glib::build_filename(relative_to, filename).c_str());
+    }
+    else {
+        pGFile = g_file_new_for_path(filename.c_str());
+    }
+    g_autofree gchar* pAbsPath = g_file_get_path(pGFile);
+    g_object_unref(pGFile);
+    retFilepath = pAbsPath;
+    return retFilepath;
+}
+
 void _locale_env_vars_set_for_external_cmd(const bool isPre)
 {
     for (const auto& currPair : _alteredLocaleEnvVars) {
@@ -101,8 +118,7 @@ bool is_directory(const fs::path& p)
 
 bool copy_file(const path& from, const path& to)
 {
-    try
-    {
+    try {
         Glib::RefPtr<Gio::File> rFileFrom = Gio::File::create_for_path(from.string());
         Glib::RefPtr<Gio::File> rFileTo = Gio::File::create_for_path(to.string());
         return rFileFrom->copy(rFileTo, Gio::FILE_COPY_OVERWRITE);
@@ -115,8 +131,7 @@ bool copy_file(const path& from, const path& to)
 
 bool move_file(const path& from, const path& to)
 {
-    try
-    {
+    try {
         Glib::RefPtr<Gio::File> rFileFrom = Gio::File::create_for_path(from.string());
         Glib::RefPtr<Gio::File> rFileTo = Gio::File::create_for_path(to.string());
         return rFileFrom->move(rFileTo, Gio::FILE_COPY_OVERWRITE);
@@ -127,10 +142,13 @@ bool move_file(const path& from, const path& to)
     }
 }
 
-fs::path absolute(const fs::path& p)
+path absolute(const path& p)
 {
-    Glib::RefPtr<Gio::File> rFile = Gio::File::create_for_path(p.string());
-    return rFile->get_path();
+    GFile* pGFile = g_file_new_for_path(p.c_str());
+    g_autofree gchar* pAbsPath = g_file_get_path(pGFile);
+    path retPath{pAbsPath};
+    g_object_unref(pGFile);
+    return retPath;
 }
 
 time_t getmtime(const path& p)
@@ -260,20 +278,6 @@ void open_folderpath(const fs::path& folderpath, CtConfig* config)
     }
 }
 
-std::string get_content(const path& filepath)
-{
-    gchar *contents = NULL;
-    gsize  length   = 0;
-    g_file_get_contents(filepath.c_str(), &contents, &length, NULL);
-    if (contents)
-    {
-        std::string result(contents, length);
-        g_free(contents);
-        return result;
-    }
-    return std::string();
-}
-
 path prepare_export_folder(const path& dir_place, path new_folder, bool overwrite_existing)
 {
     if (fs::is_directory(dir_place / new_folder))
@@ -331,7 +335,7 @@ fs::path get_cherrytree_localedir()
 {
     if (_exePath.parent_path() == fs::canonical(_CMAKE_BINARY_DIR)) {
         // we're running from the build sources
-        return Glib::canonicalize_filename(Glib::build_filename(_CMAKE_SOURCE_DIR, "po"));
+        return fs_canonicalize_filename(Glib::build_filename(_CMAKE_SOURCE_DIR, "po"));
     }
 #ifdef _WIN32
     // e.g. cherrytree_0.99.9_win64_portable\mingw64\bin\cherrytree.exe
@@ -351,16 +355,57 @@ fs::path get_cherrytree_configdir()
     return Glib::build_filename(Glib::get_user_config_dir(), CtConst::APP_NAME);
 }
 
-fs::path get_cherrytree_lang_filepath()
+std::optional<fs::path> get_cherrytree_logdir()
+{
+    const fs::path logcfgFilepath = fs::get_cherrytree_logcfg_filepath();
+    if (not fs::is_regular_file(logcfgFilepath)) {
+        return std::nullopt; // file missing => no log
+    }
+    const std::string logDirpath = str::trim(Glib::file_get_contents(logcfgFilepath.string()));
+    if (logDirpath.empty()) {
+        return get_cherrytree_configdir(); // file empty => log in config dir
+    }
+    if (fs::is_directory(logDirpath)) {
+        return fs::path{logDirpath}; // valid directory => OK return it
+    }
+    return std::nullopt; // invalid directory => no log
+}
+
+fs::path get_cherrytree_print_page_setup_cfg_filepath()
+{
+    return fs::canonical(get_cherrytree_configdir() / CtConfig::PrintPageSetupFilename);
+}
+
+fs::path get_cherrytree_langcfg_filepath()
 {
     return fs::canonical(get_cherrytree_configdir() / CtConfig::LangFilename);
 }
 
+fs::path get_cherrytree_logcfg_filepath()
+{
+    return fs::canonical(get_cherrytree_configdir() / CtConfig::LogFilename);
+}
+
 fs::path get_cherrytree_config_filepath()
 {
     return fs::canonical(get_cherrytree_configdir() / CtConfig::ConfigFilename);
 }
 
+fs::path get_cherrytree_config_language_specs_dirpath()
+{
+    return get_cherrytree_configdir() / CtConfig::ConfigLanguageSpecsDirname;
+}
+
+fs::path get_cherrytree_config_styles_dirpath()
+{
+    return get_cherrytree_configdir() / CtConfig::ConfigStylesDirname;
+}
+
+fs::path get_cherrytree_config_user_style_filepath(const unsigned num)
+{
+    return fs::canonical(get_cherrytree_config_styles_dirpath() / ("user-style-" + std::to_string(num) + ".xml"));
+}
+
 std::string download_file(const std::string& filepath)
 {
     struct local {
@@ -437,34 +482,42 @@ path canonical(const path& p, const bool resolveSymlink)
         g_autofree gchar* pOutStr = g_file_read_link(p.c_str(), &pError);
         if (pOutStr) {
             if (g_path_is_absolute(pOutStr)) {
-                return Glib::canonicalize_filename(pOutStr);
+                return fs_canonicalize_filename(pOutStr);
             }
-            return Glib::canonicalize_filename(pOutStr, Glib::path_get_dirname(p.string()));
+            return fs_canonicalize_filename(pOutStr, Glib::path_get_dirname(p.string()));
         }
     }
-    return Glib::canonicalize_filename(p.string());
+    return fs_canonicalize_filename(p.string());
 }
 
 path canonical(const path& p, const path& base)
 {
-    return Glib::canonicalize_filename(p.string(), base.string());
+    return fs_canonicalize_filename(p.string(), base.string());
 }
 
 path relative(const path& p, const path& base)
 {
-    Glib::RefPtr<Gio::File> rFile = Gio::File::create_for_path(p.string());
-    Glib::RefPtr<Gio::File> rDir = Gio::File::create_for_path(base.string());
-    std::string rel_filepath = rDir->get_relative_path(rFile);
-    if (not rel_filepath.empty()) {
-        return rel_filepath;
+    GFile* pGFile_File = g_file_new_for_path(p.c_str());
+    GFile* pGFile_Dir = g_file_new_for_path(base.c_str());
+    auto on_scope_exit = scope_guard([&](void*) {
+        g_object_unref(pGFile_File);
+        g_object_unref(pGFile_Dir);
+    });
+    {
+        g_autofree gchar* pRelPath = g_file_get_relative_path(pGFile_Dir, pGFile_File);
+        if (pRelPath) {
+            return path{pRelPath};
+        }
     }
     unsigned countUp{0};
-    while (rDir->has_parent()) {
-        rDir = rDir->get_parent();
+    while (g_file_has_parent(pGFile_Dir, NULL)) {
+        GFile* pGFile_TmpDir = g_file_get_parent(pGFile_Dir);
+        g_object_unref(pGFile_Dir);
+        pGFile_Dir = pGFile_TmpDir;
         ++countUp;
-        rel_filepath = rDir->get_relative_path(rFile);
-        if (not rel_filepath.empty()) {
-            path retPath{rel_filepath};
+        g_autofree gchar* pRelPath = g_file_get_relative_path(pGFile_Dir, pGFile_File);
+        if (pRelPath) {
+            path retPath{pRelPath};
             for (unsigned i = 0; i < countUp; ++i) {
                 retPath = ".." / retPath;
             }
@@ -495,19 +548,18 @@ path path::stem() const
     return name.substr(0, dot_pos);
 }
 
-std::string path::native() const
-{
-    return _get_platform_path(_path);
-}
-
-std::string path::_get_platform_path(std::string filepath)
+std::string path::string_native() const
 {
 #ifdef _WIN32
-    filepath = str::replace(filepath, CtConst::CHAR_SLASH, CtConst::CHAR_BSLASH);
+    return str::replace(_path, CtConst::CHAR_SLASH, CtConst::CHAR_BSLASH);
 #else
-    filepath = str::replace(filepath, CtConst::CHAR_BSLASH, CtConst::CHAR_SLASH);
+    return str::replace(_path, CtConst::CHAR_BSLASH, CtConst::CHAR_SLASH);
 #endif
-    return filepath;
 }
 
-} // namespace fs 
+std::string path::string_unix() const
+{
+    return str::replace(_path, CtConst::CHAR_BSLASH, CtConst::CHAR_SLASH);
+}
+
+} // namespace fs
