@@ -1,7 +1,7 @@
 /*
  * ct_storage_control.cc
  *
- * Copyright 2009-2020
+ * Copyright 2009-2021
  * Giuseppe Penone <giuspen@gmail.com>
  * Evgenii Gurianov <https://github.com/txe>
  *
@@ -128,7 +128,7 @@ std::unique_ptr<CtStorageEntity> get_entity_by_type(CtMainWin* pCtMainWin, CtDoc
         // encrypt the file
         if (file_path != extracted_file_path)
         {
-            storage->close_connect(); // temporary, because of sqlite keepig the file
+            storage->close_connect(); // temporary, because of sqlite keeping the file
             if (!_package_file(extracted_file_path, file_path, password))
                 throw std::runtime_error("couldn't encrypt the file");
             storage->reopen_connect();
@@ -206,7 +206,7 @@ bool CtStorageControl::save(bool need_vacuum, Glib::ustring &error)
         // encrypt the file
         if (_file_path != _extracted_file_path)
         {
-            _storage->close_connect(); // temporary, because of sqlite keepig the file
+            _storage->close_connect(); // temporary, because of sqlite keeping the file
             if (!_package_file(_extracted_file_path, _file_path, _password))
                 throw std::runtime_error("couldn't encrypt the file");
             _storage->reopen_connect();
@@ -257,6 +257,10 @@ Glib::RefPtr<Gsv::Buffer> CtStorageControl::get_delayed_text_buffer(const gint64
     {
         if (password.empty()) {
             CtDialogTextEntry dialogTextEntry(title, true/*forPassword*/, pCtMainWin);
+            auto on_scope_exit = scope_guard([pCtMainWin](void*) {
+                pCtMainWin->set_systray_can_hide(true);
+            });
+            pCtMainWin->set_systray_can_hide(false);
             if (Gtk::RESPONSE_OK != dialogTextEntry.run()) {
                 // no password, user cancels operation, return empty path
                 return fs::path{};
@@ -280,10 +284,17 @@ Glib::RefPtr<Gsv::Buffer> CtStorageControl::get_delayed_text_buffer(const gint64
     }
 }
 
-/*static*/ bool CtStorageControl::_package_file(const fs::path& file_from, const fs::path& file_to, const Glib::ustring& password)
+/*static*/bool CtStorageControl::_package_file(const fs::path& file_from, const fs::path& file_to, const Glib::ustring& password)
 {
-    return 0 == CtP7zaIface::p7za_archive(file_from.c_str(), file_to.c_str(), password.c_str())
-            && fs::is_regular_file(file_to);
+    if (0 != CtP7zaIface::p7za_archive(file_from.c_str(), file_to.c_str(), password.c_str())) {
+        spdlog::debug("!! p7za_archive {} -> {}", file_from.c_str(), file_to.c_str());
+        return false;
+    }
+    if (not fs::is_regular_file(file_to)) {
+        spdlog::debug("!! is_regular_file {}", file_to);
+        return false;
+    }
+    return true;
 }
 
 void CtStorageControl::_put_in_backup(const fs::path& main_backup)
@@ -412,7 +423,7 @@ void CtStorageControl::pending_edit_db_bookmarks()
     _syncPending.bookmarks_to_write = true;
 }
 
-void CtStorageControl::add_nodes_from_storage(const fs::path& path)
+void CtStorageControl::add_nodes_from_storage(const fs::path& path, Gtk::TreeIter parent_iter)
 {
     if (!fs::is_regular_file(path)) {
         throw std::runtime_error(fmt::format("File: {} - is not a regular file", path));
@@ -429,9 +440,9 @@ void CtStorageControl::add_nodes_from_storage(const fs::path& path)
     }
 
     std::unique_ptr<CtStorageEntity> storage = get_entity_by_type(_pCtMainWin, fs::get_doc_type(extracted_file_path));
-    storage->import_nodes(extracted_file_path);
+    storage->import_nodes(extracted_file_path, parent_iter);
 
-    _pCtMainWin->get_tree_store().nodes_sequences_fix(Gtk::TreeIter(), false);
+    _pCtMainWin->get_tree_store().nodes_sequences_fix(parent_iter, false);
     _pCtMainWin->update_window_save_needed();
 }
 
