@@ -185,12 +185,15 @@ void CtStorageSqlite::test_connection()
     if (_file_path.empty()) return;
 
     auto test_readwrite = [&]() {
-        try
-        {
+        try {
             _exec_no_callback("CREATE TABLE IF NOT EXISTS test_table (id)");
             _exec_no_callback("DROP TABLE IF EXISTS test_table");
             return true;
-        } catch (std::exception&) { return false; }
+        }
+        catch (std::exception& e) {
+            spdlog::debug("{} {}", __FUNCTION__, e.what());
+            return false;
+        }
         return true;
     };
 
@@ -199,14 +202,13 @@ void CtStorageSqlite::test_connection()
 
     _close_db();
 
-    // todo: fix for win32
-#ifndef _WIN32
-    usleep(500 * 1000); // wait 0.5 sec, file can be block by sync program like Dropbox
-#endif
+    g_usleep(500 * 1000); // wait 0.5 sec, file can be block by sync program like Dropbox
 
     try {
         _open_db(_file_path);
-    } catch(std::exception&) {
+    }
+    catch(std::exception& e) {
+        spdlog::debug("{} {}", __FUNCTION__, e.what());
         throw std::runtime_error(str::format(_("%s write failed - file is missing. Reattach usb driver or shared resource"), _file_path));
     }
     if (!test_readwrite())
@@ -248,8 +250,7 @@ bool CtStorageSqlite::populate_treestore(const fs::path& file_path, Glib::ustrin
         // keep db open for lazy node buffer loading
         return true;
     }
-    catch (std::exception& e)
-    {
+    catch (std::exception& e) {
         _close_db();
         error = e.what();
         return false;
@@ -346,8 +347,7 @@ bool CtStorageSqlite::save_treestore(const fs::path& file_path,
 
         return true;
     }
-    catch (std::exception& e)
-    {
+    catch (std::exception& e) {
         error = e.what();
         return false;
     }
@@ -820,7 +820,7 @@ void CtStorageSqlite::_exec_bind_int64(const char* sqlCmd, const gint64 bind_int
         throw std::runtime_error(ERR_SQLITE_STEP + sqlite3_errmsg(_pDb));
 }
 
-void CtStorageSqlite::import_nodes(const fs::path& path)
+void CtStorageSqlite::import_nodes(const fs::path& path, const Gtk::TreeIter& parent_iter)
 {
     _open_db(path); // storage is temp so can just open db
     if (!_check_database_integrity()) return;
@@ -834,10 +834,10 @@ void CtStorageSqlite::import_nodes(const fs::path& path)
             add_node_func(child_id, ++child_sequence, node_iter);
         }
     };
-    gint64 sequence = 0;
-    for (auto node_id : _get_children_node_ids_from_db(0))
-        add_node_func(node_id, ++sequence, Gtk::TreeIter());
-
+    gint64 sequence{0};
+    for (auto node_id : _get_children_node_ids_from_db(0)) {
+        add_node_func(node_id, ++sequence, parent_iter);
+    }
     _close_db();
 }
 
