@@ -1,7 +1,7 @@
 /*
  * ct_treestore.h
  *
- * Copyright 2009-2020
+ * Copyright 2009-2021
  * Giuseppe Penone <giuspen@gmail.com>
  * Evgenii Gurianov <https://github.com/txe>
  *
@@ -103,6 +103,9 @@ public:
     std::string   get_node_foreground() const;
     std::string   get_node_syntax_highlighting() const;
     bool          get_node_is_rich_text() const;
+    bool          get_node_is_plain_text() const;
+    bool          get_node_is_text() const;
+    bool          get_node_is_code() const { return not get_node_is_text(); }
     gint64        get_node_creating_time() const;
     gint64        get_node_modification_time() const;
     void          set_node_modification_time(const gint64 modification_time);
@@ -157,7 +160,8 @@ public:
 
     void treeview_set_tree_path_n_text_cursor(CtTreeView* pTreeView,
                                               const std::string& node_path,
-                                              const int cursor_pos);
+                                              const int cursor_pos,
+                                              const int v_adj_val);
     std::string treeview_get_tree_expanded_collapsed_string(Gtk::TreeView& treeView);
     void        treeview_set_tree_expanded_collapsed_string(const std::string& expanded_collapsed_string, Gtk::TreeView& treeView, bool nodes_bookm_exp);
 
